# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class AchTransactionSubtypes(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The set of valid ACH transaction subtypes
    """


    class MetaOapg:
        enum_value_to_name = {
            "INCOMING_CREDIT": "INCOMING_CREDIT",
            "INCOMING_CREDIT_CONTESTED_RETURN": "INCOMING_CREDIT_CONTESTED_RETURN",
            "INCOMING_CREDIT_DISHONORED_RETURN": "INCOMING_CREDIT_DISHONORED_RETURN",
            "INCOMING_CREDIT_RETURN": "INCOMING_CREDIT_RETURN",
            "INCOMING_CREDIT_REVERSAL": "INCOMING_CREDIT_REVERSAL",
            "INCOMING_DEBIT": "INCOMING_DEBIT",
            "INCOMING_DEBIT_CONTESTED_RETURN": "INCOMING_DEBIT_CONTESTED_RETURN",
            "INCOMING_DEBIT_DISHONORED_RETURN": "INCOMING_DEBIT_DISHONORED_RETURN",
            "INCOMING_DEBIT_DISHONORED_RETURN_REVERSAL": "INCOMING_DEBIT_DISHONORED_RETURN_REVERSAL",
            "INCOMING_DEBIT_RETURN": "INCOMING_DEBIT_RETURN",
            "INCOMING_DEBIT_RETURN_REVERSAL": "INCOMING_DEBIT_RETURN_REVERSAL",
            "INCOMING_DEBIT_REVERSAL": "INCOMING_DEBIT_REVERSAL",
            "OUTGOING_CREDIT": "OUTGOING_CREDIT",
            "OUTGOING_CREDIT_CONTESTED_RETURN": "OUTGOING_CREDIT_CONTESTED_RETURN",
            "OUTGOING_CREDIT_DISHONORED_RETURN": "OUTGOING_CREDIT_DISHONORED_RETURN",
            "OUTGOING_CREDIT_RETURN": "OUTGOING_CREDIT_RETURN",
            "OUTGOING_CREDIT_REVERSAL": "OUTGOING_CREDIT_REVERSAL",
            "OUTGOING_DEBIT": "OUTGOING_DEBIT",
            "OUTGOING_DEBIT_CONTESTED_RETURN": "OUTGOING_DEBIT_CONTESTED_RETURN",
            "OUTGOING_DEBIT_DISHONORED_RETURN": "OUTGOING_DEBIT_DISHONORED_RETURN",
            "OUTGOING_DEBIT_RETURN": "OUTGOING_DEBIT_RETURN",
            "OUTGOING_DEBIT_REVERSAL": "OUTGOING_DEBIT_REVERSAL",
            "PRENOTE": "PRENOTE",
            "TEMP_HOLD": "TEMP_HOLD",
        }
    
    @schemas.classproperty
    def INCOMING_CREDIT(cls):
        return cls("INCOMING_CREDIT")
    
    @schemas.classproperty
    def INCOMING_CREDIT_CONTESTED_RETURN(cls):
        return cls("INCOMING_CREDIT_CONTESTED_RETURN")
    
    @schemas.classproperty
    def INCOMING_CREDIT_DISHONORED_RETURN(cls):
        return cls("INCOMING_CREDIT_DISHONORED_RETURN")
    
    @schemas.classproperty
    def INCOMING_CREDIT_RETURN(cls):
        return cls("INCOMING_CREDIT_RETURN")
    
    @schemas.classproperty
    def INCOMING_CREDIT_REVERSAL(cls):
        return cls("INCOMING_CREDIT_REVERSAL")
    
    @schemas.classproperty
    def INCOMING_DEBIT(cls):
        return cls("INCOMING_DEBIT")
    
    @schemas.classproperty
    def INCOMING_DEBIT_CONTESTED_RETURN(cls):
        return cls("INCOMING_DEBIT_CONTESTED_RETURN")
    
    @schemas.classproperty
    def INCOMING_DEBIT_DISHONORED_RETURN(cls):
        return cls("INCOMING_DEBIT_DISHONORED_RETURN")
    
    @schemas.classproperty
    def INCOMING_DEBIT_DISHONORED_RETURN_REVERSAL(cls):
        return cls("INCOMING_DEBIT_DISHONORED_RETURN_REVERSAL")
    
    @schemas.classproperty
    def INCOMING_DEBIT_RETURN(cls):
        return cls("INCOMING_DEBIT_RETURN")
    
    @schemas.classproperty
    def INCOMING_DEBIT_RETURN_REVERSAL(cls):
        return cls("INCOMING_DEBIT_RETURN_REVERSAL")
    
    @schemas.classproperty
    def INCOMING_DEBIT_REVERSAL(cls):
        return cls("INCOMING_DEBIT_REVERSAL")
    
    @schemas.classproperty
    def OUTGOING_CREDIT(cls):
        return cls("OUTGOING_CREDIT")
    
    @schemas.classproperty
    def OUTGOING_CREDIT_CONTESTED_RETURN(cls):
        return cls("OUTGOING_CREDIT_CONTESTED_RETURN")
    
    @schemas.classproperty
    def OUTGOING_CREDIT_DISHONORED_RETURN(cls):
        return cls("OUTGOING_CREDIT_DISHONORED_RETURN")
    
    @schemas.classproperty
    def OUTGOING_CREDIT_RETURN(cls):
        return cls("OUTGOING_CREDIT_RETURN")
    
    @schemas.classproperty
    def OUTGOING_CREDIT_REVERSAL(cls):
        return cls("OUTGOING_CREDIT_REVERSAL")
    
    @schemas.classproperty
    def OUTGOING_DEBIT(cls):
        return cls("OUTGOING_DEBIT")
    
    @schemas.classproperty
    def OUTGOING_DEBIT_CONTESTED_RETURN(cls):
        return cls("OUTGOING_DEBIT_CONTESTED_RETURN")
    
    @schemas.classproperty
    def OUTGOING_DEBIT_DISHONORED_RETURN(cls):
        return cls("OUTGOING_DEBIT_DISHONORED_RETURN")
    
    @schemas.classproperty
    def OUTGOING_DEBIT_RETURN(cls):
        return cls("OUTGOING_DEBIT_RETURN")
    
    @schemas.classproperty
    def OUTGOING_DEBIT_REVERSAL(cls):
        return cls("OUTGOING_DEBIT_REVERSAL")
    
    @schemas.classproperty
    def PRENOTE(cls):
        return cls("PRENOTE")
    
    @schemas.classproperty
    def TEMP_HOLD(cls):
        return cls("TEMP_HOLD")



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class ApplicationRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "business_name",
            "business_phone",
            "partner_id",
            "business_address",
            "bank_id",
            "business_tax_id",
            "business_type",
            "doing_business_as",
            "enabled",
            "max_transaction_amount",
        }
        
        class properties:
            bank_id = schemas.IntSchema
        
            @staticmethod
            def business_address() -> typing.Type['Address1']:
                return Address1
            business_name = schemas.StrSchema
            business_phone = schemas.StrSchema
            
            
            class business_tax_id(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 9
                    min_length = 9
            
            
            class business_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "INDIVIDUAL_SOLE_PROPRIETORSHIP": "INDIVIDUAL_SOLE_PROPRIETORSHIP",
                        "CORPORATION": "CORPORATION",
                        "LIMITED_LIABILITY_COMPANY": "LIMITED_LIABILITY_COMPANY",
                        "PARTNERSHIP": "PARTNERSHIP",
                        "ASSOCIATION_ESTATE_TRUST": "ASSOCIATION_ESTATE_TRUST",
                        "TAX_EXEMPT_ORGANIZATION": "TAX_EXEMPT_ORGANIZATION",
                        "INTERNATIONAL_ORGANIZATION": "INTERNATIONAL_ORGANIZATION",
                        "GOVERNMENT_AGENCY": "GOVERNMENT_AGENCY",
                    }
                
                @schemas.classproperty
                def INDIVIDUAL_SOLE_PROPRIETORSHIP(cls):
                    return cls("INDIVIDUAL_SOLE_PROPRIETORSHIP")
                
                @schemas.classproperty
                def CORPORATION(cls):
                    return cls("CORPORATION")
                
                @schemas.classproperty
                def LIMITED_LIABILITY_COMPANY(cls):
                    return cls("LIMITED_LIABILITY_COMPANY")
                
                @schemas.classproperty
                def PARTNERSHIP(cls):
                    return cls("PARTNERSHIP")
                
                @schemas.classproperty
                def ASSOCIATION_ESTATE_TRUST(cls):
                    return cls("ASSOCIATION_ESTATE_TRUST")
                
                @schemas.classproperty
                def TAX_EXEMPT_ORGANIZATION(cls):
                    return cls("TAX_EXEMPT_ORGANIZATION")
                
                @schemas.classproperty
                def INTERNATIONAL_ORGANIZATION(cls):
                    return cls("INTERNATIONAL_ORGANIZATION")
                
                @schemas.classproperty
                def GOVERNMENT_AGENCY(cls):
                    return cls("GOVERNMENT_AGENCY")
            doing_business_as = schemas.StrSchema
            enabled = schemas.BoolSchema
            max_transaction_amount = schemas.IntSchema
            partner_id = schemas.IntSchema
        
            @staticmethod
            def dob() -> typing.Type['ExternalPaymentDate']:
                return ExternalPaymentDate
            email = schemas.StrSchema
            first_name = schemas.StrSchema
        
            @staticmethod
            def incorporation_date() -> typing.Type['ExternalPaymentDate']:
                return ExternalPaymentDate
            last_name = schemas.StrSchema
        
            @staticmethod
            def personal_address() -> typing.Type['Address1']:
                return Address1
            phone = schemas.StrSchema
            principal_percentage_ownership = schemas.StrSchema
            
            
            class tax_id(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 9
                    min_length = 9
            title = schemas.StrSchema
            url = schemas.StrSchema
            __annotations__ = {
                "bank_id": bank_id,
                "business_address": business_address,
                "business_name": business_name,
                "business_phone": business_phone,
                "business_tax_id": business_tax_id,
                "business_type": business_type,
                "doing_business_as": doing_business_as,
                "enabled": enabled,
                "max_transaction_amount": max_transaction_amount,
                "partner_id": partner_id,
                "dob": dob,
                "email": email,
                "first_name": first_name,
                "incorporation_date": incorporation_date,
                "last_name": last_name,
                "personal_address": personal_address,
                "phone": phone,
                "principal_percentage_ownership": principal_percentage_ownership,
                "tax_id": tax_id,
                "title": title,
                "url": url,
            }
    
    business_name: MetaOapg.properties.business_name
    business_phone: MetaOapg.properties.business_phone
    partner_id: MetaOapg.properties.partner_id
    business_address: 'Address1'
    bank_id: MetaOapg.properties.bank_id
    business_tax_id: MetaOapg.properties.business_tax_id
    business_type: MetaOapg.properties.business_type
    doing_business_as: MetaOapg.properties.doing_business_as
    enabled: MetaOapg.properties.enabled
    max_transaction_amount: MetaOapg.properties.max_transaction_amount
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bank_id"]) -> MetaOapg.properties.bank_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_address"]) -> 'Address1': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_name"]) -> MetaOapg.properties.business_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_phone"]) -> MetaOapg.properties.business_phone: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_tax_id"]) -> MetaOapg.properties.business_tax_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_type"]) -> MetaOapg.properties.business_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["doing_business_as"]) -> MetaOapg.properties.doing_business_as: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["max_transaction_amount"]) -> MetaOapg.properties.max_transaction_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["partner_id"]) -> MetaOapg.properties.partner_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dob"]) -> 'ExternalPaymentDate': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["first_name"]) -> MetaOapg.properties.first_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["incorporation_date"]) -> 'ExternalPaymentDate': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_name"]) -> MetaOapg.properties.last_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["personal_address"]) -> 'Address1': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["phone"]) -> MetaOapg.properties.phone: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["principal_percentage_ownership"]) -> MetaOapg.properties.principal_percentage_ownership: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tax_id"]) -> MetaOapg.properties.tax_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["bank_id", "business_address", "business_name", "business_phone", "business_tax_id", "business_type", "doing_business_as", "enabled", "max_transaction_amount", "partner_id", "dob", "email", "first_name", "incorporation_date", "last_name", "personal_address", "phone", "principal_percentage_ownership", "tax_id", "title", "url", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bank_id"]) -> MetaOapg.properties.bank_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_address"]) -> 'Address1': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_name"]) -> MetaOapg.properties.business_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_phone"]) -> MetaOapg.properties.business_phone: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_tax_id"]) -> MetaOapg.properties.business_tax_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_type"]) -> MetaOapg.properties.business_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["doing_business_as"]) -> MetaOapg.properties.doing_business_as: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["max_transaction_amount"]) -> MetaOapg.properties.max_transaction_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["partner_id"]) -> MetaOapg.properties.partner_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dob"]) -> typing.Union['ExternalPaymentDate', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["email"]) -> typing.Union[MetaOapg.properties.email, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["first_name"]) -> typing.Union[MetaOapg.properties.first_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["incorporation_date"]) -> typing.Union['ExternalPaymentDate', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_name"]) -> typing.Union[MetaOapg.properties.last_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["personal_address"]) -> typing.Union['Address1', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["phone"]) -> typing.Union[MetaOapg.properties.phone, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["principal_percentage_ownership"]) -> typing.Union[MetaOapg.properties.principal_percentage_ownership, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tax_id"]) -> typing.Union[MetaOapg.properties.tax_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> typing.Union[MetaOapg.properties.title, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> typing.Union[MetaOapg.properties.url, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["bank_id", "business_address", "business_name", "business_phone", "business_tax_id", "business_type", "doing_business_as", "enabled", "max_transaction_amount", "partner_id", "dob", "email", "first_name", "incorporation_date", "last_name", "personal_address", "phone", "principal_percentage_ownership", "tax_id", "title", "url", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        business_name: typing.Union[MetaOapg.properties.business_name, str, ],
        business_phone: typing.Union[MetaOapg.properties.business_phone, str, ],
        partner_id: typing.Union[MetaOapg.properties.partner_id, decimal.Decimal, int, ],
        business_address: 'Address1',
        bank_id: typing.Union[MetaOapg.properties.bank_id, decimal.Decimal, int, ],
        business_tax_id: typing.Union[MetaOapg.properties.business_tax_id, str, ],
        business_type: typing.Union[MetaOapg.properties.business_type, str, ],
        doing_business_as: typing.Union[MetaOapg.properties.doing_business_as, str, ],
        enabled: typing.Union[MetaOapg.properties.enabled, bool, ],
        max_transaction_amount: typing.Union[MetaOapg.properties.max_transaction_amount, decimal.Decimal, int, ],
        dob: typing.Union['ExternalPaymentDate', schemas.Unset] = schemas.unset,
        email: typing.Union[MetaOapg.properties.email, str, schemas.Unset] = schemas.unset,
        first_name: typing.Union[MetaOapg.properties.first_name, str, schemas.Unset] = schemas.unset,
        incorporation_date: typing.Union['ExternalPaymentDate', schemas.Unset] = schemas.unset,
        last_name: typing.Union[MetaOapg.properties.last_name, str, schemas.Unset] = schemas.unset,
        personal_address: typing.Union['Address1', schemas.Unset] = schemas.unset,
        phone: typing.Union[MetaOapg.properties.phone, str, schemas.Unset] = schemas.unset,
        principal_percentage_ownership: typing.Union[MetaOapg.properties.principal_percentage_ownership, str, schemas.Unset] = schemas.unset,
        tax_id: typing.Union[MetaOapg.properties.tax_id, str, schemas.Unset] = schemas.unset,
        title: typing.Union[MetaOapg.properties.title, str, schemas.Unset] = schemas.unset,
        url: typing.Union[MetaOapg.properties.url, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ApplicationRequest':
        return super().__new__(
            cls,
            *_args,
            business_name=business_name,
            business_phone=business_phone,
            partner_id=partner_id,
            business_address=business_address,
            bank_id=bank_id,
            business_tax_id=business_tax_id,
            business_type=business_type,
            doing_business_as=doing_business_as,
            enabled=enabled,
            max_transaction_amount=max_transaction_amount,
            dob=dob,
            email=email,
            first_name=first_name,
            incorporation_date=incorporation_date,
            last_name=last_name,
            personal_address=personal_address,
            phone=phone,
            principal_percentage_ownership=principal_percentage_ownership,
            tax_id=tax_id,
            title=title,
            url=url,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.address1 import Address1
from synctera_client.model.external_payment_date import ExternalPaymentDate



from synctera_client.paths.customers_customer_id_verifications.get import ApiForget
from synctera_client.paths.customers_customer_id_verifications.post import ApiForpost


class CustomersCustomerIdVerifications(
    ApiForget,
    ApiForpost,
):
    pass



from synctera_client.paths.payment_schedules.get import ApiForget
from synctera_client.paths.payment_schedules.post import ApiForpost


class PaymentSchedules(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class FinancialRequestModel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "mid",
            "card_acceptor",
            "card_id",
        }
        
        class properties:
            amount = schemas.IntSchema
        
            @staticmethod
            def card_acceptor() -> typing.Type['CardAcceptorModel']:
                return CardAcceptorModel
            card_id = schemas.UUIDSchema
            
            
            class mid(
                schemas.StrSchema
            ):
                pass
            cash_back_amount = schemas.IntSchema
            is_pre_auth = schemas.BoolSchema
            
            
            class pin(
                schemas.StrSchema
            ):
                pass
        
            @staticmethod
            def transaction_options() -> typing.Type['TransactionOptions']:
                return TransactionOptions
            __annotations__ = {
                "amount": amount,
                "card_acceptor": card_acceptor,
                "card_id": card_id,
                "mid": mid,
                "cash_back_amount": cash_back_amount,
                "is_pre_auth": is_pre_auth,
                "pin": pin,
                "transaction_options": transaction_options,
            }
    
    amount: MetaOapg.properties.amount
    mid: MetaOapg.properties.mid
    card_acceptor: 'CardAcceptorModel'
    card_id: MetaOapg.properties.card_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["card_acceptor"]) -> 'CardAcceptorModel': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["card_id"]) -> MetaOapg.properties.card_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mid"]) -> MetaOapg.properties.mid: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cash_back_amount"]) -> MetaOapg.properties.cash_back_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_pre_auth"]) -> MetaOapg.properties.is_pre_auth: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pin"]) -> MetaOapg.properties.pin: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_options"]) -> 'TransactionOptions': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "card_acceptor", "card_id", "mid", "cash_back_amount", "is_pre_auth", "pin", "transaction_options", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["card_acceptor"]) -> 'CardAcceptorModel': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["card_id"]) -> MetaOapg.properties.card_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mid"]) -> MetaOapg.properties.mid: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cash_back_amount"]) -> typing.Union[MetaOapg.properties.cash_back_amount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_pre_auth"]) -> typing.Union[MetaOapg.properties.is_pre_auth, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pin"]) -> typing.Union[MetaOapg.properties.pin, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_options"]) -> typing.Union['TransactionOptions', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "card_acceptor", "card_id", "mid", "cash_back_amount", "is_pre_auth", "pin", "transaction_options", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        mid: typing.Union[MetaOapg.properties.mid, str, ],
        card_acceptor: 'CardAcceptorModel',
        card_id: typing.Union[MetaOapg.properties.card_id, str, uuid.UUID, ],
        cash_back_amount: typing.Union[MetaOapg.properties.cash_back_amount, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        is_pre_auth: typing.Union[MetaOapg.properties.is_pre_auth, bool, schemas.Unset] = schemas.unset,
        pin: typing.Union[MetaOapg.properties.pin, str, schemas.Unset] = schemas.unset,
        transaction_options: typing.Union['TransactionOptions', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'FinancialRequestModel':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            mid=mid,
            card_acceptor=card_acceptor,
            card_id=card_id,
            cash_back_amount=cash_back_amount,
            is_pre_auth=is_pre_auth,
            pin=pin,
            transaction_options=transaction_options,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.card_acceptor_model import CardAcceptorModel
from synctera_client.model.transaction_options import TransactionOptions



from synctera_client.paths.cards_digital_wallet_tokens_digital_wallet_token_id.get import ApiForget
from synctera_client.paths.cards_digital_wallet_tokens_digital_wallet_token_id.patch import ApiForpatch


class CardsDigitalWalletTokensDigitalWalletTokenId(
    ApiForget,
    ApiForpatch,
):
    pass



from synctera_client.paths.customers_customer_id_employment.get import ApiForget
from synctera_client.paths.customers_customer_id_employment.post import ApiForpost


class CustomersCustomerIdEmployment(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class InternalAccount(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "currency",
            "status",
        }
        
        class properties:
            
            
            class currency(
                schemas.StrSchema
            ):
                pass
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def ACTIVE(cls):
                    return cls("ACTIVE")
            
            
            class account_number(
                schemas.StrSchema
            ):
                pass
        
            @staticmethod
            def account_type() -> typing.Type['InternalAccountType']:
                return InternalAccountType
            
            
            class balances(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Balance']:
                        return Balance
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Balance'], typing.List['Balance']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'balances':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Balance':
                    return super().__getitem__(i)
            
            
            class bank_routing(
                schemas.StrSchema
            ):
                pass
            creation_time = schemas.DateTimeSchema
            description = schemas.StrSchema
            
            
            class gl_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def ASSET(cls):
                    return cls("ASSET")
                
                @schemas.classproperty
                def LIABILITY(cls):
                    return cls("LIABILITY")
                
                @schemas.classproperty
                def EXPENSE(cls):
                    return cls("EXPENSE")
                
                @schemas.classproperty
                def REVENUE(cls):
                    return cls("REVENUE")
            id = schemas.UUIDSchema
            is_system_acc = schemas.BoolSchema
            last_updated_time = schemas.DateTimeSchema
        
            @staticmethod
            def purpose() -> typing.Type['InternalAccountPurpose']:
                return InternalAccountPurpose
            __annotations__ = {
                "currency": currency,
                "status": status,
                "account_number": account_number,
                "account_type": account_type,
                "balances": balances,
                "bank_routing": bank_routing,
                "creation_time": creation_time,
                "description": description,
                "gl_type": gl_type,
                "id": id,
                "is_system_acc": is_system_acc,
                "last_updated_time": last_updated_time,
                "purpose": purpose,
            }
    
    currency: MetaOapg.properties.currency
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_number"]) -> MetaOapg.properties.account_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_type"]) -> 'InternalAccountType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balances"]) -> MetaOapg.properties.balances: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bank_routing"]) -> MetaOapg.properties.bank_routing: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gl_type"]) -> MetaOapg.properties.gl_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_system_acc"]) -> MetaOapg.properties.is_system_acc: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["purpose"]) -> 'InternalAccountPurpose': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["currency", "status", "account_number", "account_type", "balances", "bank_routing", "creation_time", "description", "gl_type", "id", "is_system_acc", "last_updated_time", "purpose", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_number"]) -> typing.Union[MetaOapg.properties.account_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_type"]) -> typing.Union['InternalAccountType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balances"]) -> typing.Union[MetaOapg.properties.balances, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bank_routing"]) -> typing.Union[MetaOapg.properties.bank_routing, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> typing.Union[MetaOapg.properties.creation_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gl_type"]) -> typing.Union[MetaOapg.properties.gl_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_system_acc"]) -> typing.Union[MetaOapg.properties.is_system_acc, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> typing.Union[MetaOapg.properties.last_updated_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["purpose"]) -> typing.Union['InternalAccountPurpose', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["currency", "status", "account_number", "account_type", "balances", "bank_routing", "creation_time", "description", "gl_type", "id", "is_system_acc", "last_updated_time", "purpose", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        account_number: typing.Union[MetaOapg.properties.account_number, str, schemas.Unset] = schemas.unset,
        account_type: typing.Union['InternalAccountType', schemas.Unset] = schemas.unset,
        balances: typing.Union[MetaOapg.properties.balances, list, tuple, schemas.Unset] = schemas.unset,
        bank_routing: typing.Union[MetaOapg.properties.bank_routing, str, schemas.Unset] = schemas.unset,
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        gl_type: typing.Union[MetaOapg.properties.gl_type, str, schemas.Unset] = schemas.unset,
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        is_system_acc: typing.Union[MetaOapg.properties.is_system_acc, bool, schemas.Unset] = schemas.unset,
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, schemas.Unset] = schemas.unset,
        purpose: typing.Union['InternalAccountPurpose', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'InternalAccount':
        return super().__new__(
            cls,
            *_args,
            currency=currency,
            status=status,
            account_number=account_number,
            account_type=account_type,
            balances=balances,
            bank_routing=bank_routing,
            creation_time=creation_time,
            description=description,
            gl_type=gl_type,
            id=id,
            is_system_acc=is_system_acc,
            last_updated_time=last_updated_time,
            purpose=purpose,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.balance import Balance
from synctera_client.model.internal_account_purpose import InternalAccountPurpose
from synctera_client.model.internal_account_type import InternalAccountType



from synctera_client.paths.documents_document_id.get import ApiForget
from synctera_client.paths.documents_document_id.patch import ApiForpatch


class DocumentsDocumentId(
    ApiForget,
    ApiForpatch,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from synctera_client import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401

from synctera_client.model.error import Error
from synctera_client.model.patch_external_account import PatchExternalAccount
from synctera_client.model.external_account import ExternalAccount

from . import path

# Header params
IdempotencyKeySchema = schemas.StrSchema
RequestRequiredHeaderParams = typing_extensions.TypedDict(
    'RequestRequiredHeaderParams',
    {
    }
)
RequestOptionalHeaderParams = typing_extensions.TypedDict(
    'RequestOptionalHeaderParams',
    {
        'Idempotency-Key': typing.Union[IdempotencyKeySchema, str, ],
    },
    total=False
)


class RequestHeaderParams(RequestRequiredHeaderParams, RequestOptionalHeaderParams):
    pass


request_header_idempotency_key = api_client.HeaderParameter(
    name="Idempotency-Key",
    style=api_client.ParameterStyle.SIMPLE,
    schema=IdempotencyKeySchema,
)
# Path params
ExternalAccountIdSchema = schemas.UUIDSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'external_account_id': typing.Union[ExternalAccountIdSchema, str, uuid.UUID, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_external_account_id = api_client.PathParameter(
    name="external_account_id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=ExternalAccountIdSchema,
    required=True,
)
# body param
SchemaForRequestBodyApplicationJson = PatchExternalAccount


request_body_patch_external_account = api_client.RequestBody(
    content={
        'application/json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationJson),
    },
    required=True,
)
_auth = [
    'bearerAuth',
]
SchemaFor200ResponseBodyApplicationJson = ExternalAccount


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor401ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationProblemjson),
    },
)
SchemaFor403ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor403(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor403ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_403 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor403,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor403ResponseBodyApplicationProblemjson),
    },
)
SchemaFor404ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor404(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor404ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_404 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor404,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor404ResponseBodyApplicationProblemjson),
    },
)
SchemaFor409ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor409(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor409ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_409 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor409,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor409ResponseBodyApplicationProblemjson),
    },
)
SchemaFor422ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor422(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor422ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_422 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor422,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor422ResponseBodyApplicationProblemjson),
    },
)
SchemaFor500ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor500ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor500ResponseBodyApplicationProblemjson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '401': _response_for_401,
    '403': _response_for_403,
    '404': _response_for_404,
    '409': _response_for_409,
    '422': _response_for_422,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
    'application/problem+json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _update_external_account_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: typing_extensions.Literal["application/json"] = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _update_external_account_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def _update_external_account_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _update_external_account_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _update_external_account_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = 'application/json',
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Patch an external account
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestHeaderParams, header_params)
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_external_account_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        _headers = HTTPHeaderDict()
        for parameter in (
            request_header_idempotency_key,
        ):
            parameter_data = header_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _headers.extend(serialized_data)
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        if body is schemas.unset:
            raise exceptions.ApiValueError(
                'The required body parameter has an invalid value of: unset. Set a valid value instead')
        _fields = None
        _body = None
        serialized_data = request_body_patch_external_account.serialize(body, content_type)
        _headers.add('Content-Type', content_type)
        if 'fields' in serialized_data:
            _fields = serialized_data['fields']
        elif 'body' in serialized_data:
            _body = serialized_data['body']
        response = self.api_client.call_api(
            resource_path=used_path,
            method='patch'.upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class UpdateExternalAccount(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def update_external_account(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: typing_extensions.Literal["application/json"] = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def update_external_account(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def update_external_account(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def update_external_account(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def update_external_account(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = 'application/json',
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._update_external_account_oapg(
            body=body,
            header_params=header_params,
            path_params=path_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpatch(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def patch(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: typing_extensions.Literal["application/json"] = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def patch(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def patch(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def patch(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = ...,
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def patch(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,],
        content_type: str = 'application/json',
        header_params: RequestHeaderParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._update_external_account_oapg(
            body=body,
            header_params=header_params,
            path_params=path_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class PostedTransaction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "lead_mode",
            "data",
            "reference_id",
            "created",
            "idemkey",
            "type",
            "uuid",
            "subtype",
            "effective_date",
            "transaction_time",
            "info_only",
            "id",
            "updated",
            "posted_date",
            "tenant",
            "status",
        }
        
        class properties:
            created = schemas.DateTimeSchema
        
            @staticmethod
            def data() -> typing.Type['PostedTransactionData']:
                return PostedTransactionData
            effective_date = schemas.DateTimeSchema
            id = schemas.Int64Schema
            idemkey = schemas.StrSchema
            info_only = schemas.BoolSchema
            lead_mode = schemas.BoolSchema
            posted_date = schemas.DateTimeSchema
            
            
            class reference_id(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'reference_id':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            status = schemas.StrSchema
            subtype = schemas.StrSchema
            tenant = schemas.StrSchema
            transaction_time = schemas.DateTimeSchema
            type = schemas.StrSchema
            updated = schemas.DateTimeSchema
            uuid = schemas.UUIDSchema
            __annotations__ = {
                "created": created,
                "data": data,
                "effective_date": effective_date,
                "id": id,
                "idemkey": idemkey,
                "info_only": info_only,
                "lead_mode": lead_mode,
                "posted_date": posted_date,
                "reference_id": reference_id,
                "status": status,
                "subtype": subtype,
                "tenant": tenant,
                "transaction_time": transaction_time,
                "type": type,
                "updated": updated,
                "uuid": uuid,
            }
    
    lead_mode: MetaOapg.properties.lead_mode
    data: 'PostedTransactionData'
    reference_id: MetaOapg.properties.reference_id
    created: MetaOapg.properties.created
    idemkey: MetaOapg.properties.idemkey
    type: MetaOapg.properties.type
    uuid: MetaOapg.properties.uuid
    subtype: MetaOapg.properties.subtype
    effective_date: MetaOapg.properties.effective_date
    transaction_time: MetaOapg.properties.transaction_time
    info_only: MetaOapg.properties.info_only
    id: MetaOapg.properties.id
    updated: MetaOapg.properties.updated
    posted_date: MetaOapg.properties.posted_date
    tenant: MetaOapg.properties.tenant
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created"]) -> MetaOapg.properties.created: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> 'PostedTransactionData': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idemkey"]) -> MetaOapg.properties.idemkey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["info_only"]) -> MetaOapg.properties.info_only: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["lead_mode"]) -> MetaOapg.properties.lead_mode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["posted_date"]) -> MetaOapg.properties.posted_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reference_id"]) -> MetaOapg.properties.reference_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["subtype"]) -> MetaOapg.properties.subtype: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tenant"]) -> MetaOapg.properties.tenant: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updated"]) -> MetaOapg.properties.updated: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["uuid"]) -> MetaOapg.properties.uuid: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["created", "data", "effective_date", "id", "idemkey", "info_only", "lead_mode", "posted_date", "reference_id", "status", "subtype", "tenant", "transaction_time", "type", "updated", "uuid", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created"]) -> MetaOapg.properties.created: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> 'PostedTransactionData': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idemkey"]) -> MetaOapg.properties.idemkey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["info_only"]) -> MetaOapg.properties.info_only: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["lead_mode"]) -> MetaOapg.properties.lead_mode: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["posted_date"]) -> MetaOapg.properties.posted_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reference_id"]) -> MetaOapg.properties.reference_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["subtype"]) -> MetaOapg.properties.subtype: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tenant"]) -> MetaOapg.properties.tenant: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updated"]) -> MetaOapg.properties.updated: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["uuid"]) -> MetaOapg.properties.uuid: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["created", "data", "effective_date", "id", "idemkey", "info_only", "lead_mode", "posted_date", "reference_id", "status", "subtype", "tenant", "transaction_time", "type", "updated", "uuid", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        lead_mode: typing.Union[MetaOapg.properties.lead_mode, bool, ],
        data: 'PostedTransactionData',
        reference_id: typing.Union[MetaOapg.properties.reference_id, None, str, ],
        created: typing.Union[MetaOapg.properties.created, str, datetime, ],
        idemkey: typing.Union[MetaOapg.properties.idemkey, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        uuid: typing.Union[MetaOapg.properties.uuid, str, uuid.UUID, ],
        subtype: typing.Union[MetaOapg.properties.subtype, str, ],
        effective_date: typing.Union[MetaOapg.properties.effective_date, str, datetime, ],
        transaction_time: typing.Union[MetaOapg.properties.transaction_time, str, datetime, ],
        info_only: typing.Union[MetaOapg.properties.info_only, bool, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, ],
        updated: typing.Union[MetaOapg.properties.updated, str, datetime, ],
        posted_date: typing.Union[MetaOapg.properties.posted_date, str, datetime, ],
        tenant: typing.Union[MetaOapg.properties.tenant, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PostedTransaction':
        return super().__new__(
            cls,
            *_args,
            lead_mode=lead_mode,
            data=data,
            reference_id=reference_id,
            created=created,
            idemkey=idemkey,
            type=type,
            uuid=uuid,
            subtype=subtype,
            effective_date=effective_date,
            transaction_time=transaction_time,
            info_only=info_only,
            id=id,
            updated=updated,
            posted_date=posted_date,
            tenant=tenant,
            status=status,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.posted_transaction_data import PostedTransactionData



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.persons.post import CreatePerson
from synctera_client.paths.persons_personal_ids.post import CreatePersonalId
from synctera_client.paths.persons_personal_ids_personal_id_id.delete import DeletePersonalId
from synctera_client.paths.persons_person_id.get import GetPerson
from synctera_client.paths.persons.get import ListPersons
from synctera_client.paths.persons_person_id_prefill.post import PrefillPerson
from synctera_client.paths.persons_person_id.patch import UpdatePerson
from synctera_client.paths.persons_personal_ids_personal_id_id.patch import UpdatePersonalId


class PersonsApi(
    CreatePerson,
    CreatePersonalId,
    DeletePersonalId,
    GetPerson,
    ListPersons,
    PrefillPerson,
    UpdatePerson,
    UpdatePersonalId,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from synctera_client.paths.internal_accounts.get import ApiForget
from synctera_client.paths.internal_accounts.post import ApiForpost


class InternalAccounts(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class CardImageMode(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The image mode of a card product. If the card product supports custom card images, this value determines how the images will be handled during card issuance. REQUIRED means that cards issued with this card product must have the ID of an image that has been uploaded. Note that the image does not necessarily have to have been approved prior to the issuance request. This mode is currently disabled. REQUIRED_APPROVED_FIRST means that cards issued with this card product must have the ID of an image that has been uploaded and approved.

    """


    class MetaOapg:
        enum_value_to_name = {
            "REQUIRED": "REQUIRED",
            "REQUIRED_APPROVED_FIRST": "REQUIRED_APPROVED_FIRST",
        }
    
    @schemas.classproperty
    def REQUIRED(cls):
        return cls("REQUIRED")
    
    @schemas.classproperty
    def REQUIRED_APPROVED_FIRST(cls):
        return cls("REQUIRED_APPROVED_FIRST")



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.customers_customer_id_watchlists_alerts_alert_id.get import GetWatchlistAlert
from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.get import GetWatchlistSubscription
from synctera_client.paths.customers_customer_id_watchlists_alerts.get import ListWatchlistAlerts
from synctera_client.paths.customers_customer_id_watchlists_subscriptions.get import ListWatchlistSubscriptions
from synctera_client.paths.customers_customer_id_watchlists_suppressions.post import SuppressWatchlistEntityAlert
from synctera_client.paths.customers_customer_id_watchlists_alerts_alert_id.put import UpdateWatchlistAlert
from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.put import UpdateWatchlistSubscription
from synctera_client.paths.customers_customer_id_watchlists_subscriptions.post import WatchlistSubscribe


class WatchlistDeprecatedApi(
    GetWatchlistAlert,
    GetWatchlistSubscription,
    ListWatchlistAlerts,
    ListWatchlistSubscriptions,
    SuppressWatchlistEntityAlert,
    UpdateWatchlistAlert,
    UpdateWatchlistSubscription,
    WatchlistSubscribe,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
